define(
//begin v1.x content
({
	widgetLabel: "批处理拼写检查",
	unfound: "未找到",
	skip: "跳过",
	skipAll: "全部跳过",
	toDic: "添加到字典",
	suggestions: "建议",
	replace: "替换",
	replaceWith: "替换为",
	replaceAll: "全部替换",
	cancel: "取消",
	msg: "未找到拼写错误",
	iSkip: "跳过此处",
	iSkipAll: "跳过所有与此处相同的地方",
	iMsg: "没有拼写建议"
})
//end v1.x content
);
